<?php

use QUI\UserDownloads\Handler;
use QUI\UserDownloads\Exception as UserDownloadException;
use QUI\UserDownloads\DownloadEntry;

QUI::$Ajax->registerFunction(
    'package_quiqqer_user-downloads_ajax_backend_create',
    /**
     * Create a user download entry
     * @throws UserDownloadException
     */
    function (int|string $uid, string $data) {
        try {
            $User = QUI::getUsers()->get($uid);
            $DownloadEntry = new DownloadEntry($User);
            $data = json_decode($data, true);

            $data['title'] = json_decode($data['title'], true);
            $data['description'] = json_decode($data['description'], true);

            foreach ($data['title'] as $lang => $title) {
                $DownloadEntry->setTitle($lang, $title);
            }

            foreach ($data['description'] as $lang => $description) {
                $DownloadEntry->setDescription($lang, $description);
            }

            // QUIQQER Media URLs
            $DownloadEntry->setQuiqqerMediaUrls([]);
            $files = explode(',', $data['files']);
            $files = array_values(array_unique($files));

            foreach ($files as $quiqqerMediaUrl) {
                if (empty($quiqqerMediaUrl)) {
                    continue;
                }

                $DownloadEntry->addQuiqqerMediaItemUrl($quiqqerMediaUrl);
            }

            // Custom URLs
            $urls = json_decode($data['urls'], true);
            $DownloadEntry->setUrls([]);

            foreach ($urls as $entry) {
                $DownloadEntry->addUrl($entry['url'], $entry['title']);
            }

            Handler::addDownloadEntry($DownloadEntry);
        } catch (UserDownloadException $Exception) {
            QUI\System\Log::writeDebugException($Exception);
            throw $Exception;
        } catch (Exception $Exception) {
            QUI\System\Log::writeException($Exception);

            throw new UserDownloadException([
                'quiqqer/user-donwloads',
                'exception.ajax.backend.general'
            ]);
        }

        QUI::getMessagesHandler()->addSuccess(
            QUI::getLocale()->get(
                'quiqqer/user-downloads',
                'message.ajax.backend.create.success',
                [
                    'user' => $User->getName() . ' (#' . $User->getId() . ')'
                ]
            )
        );
    },
    ['uid', 'data'],
    'Permission::checkAdminUser'
);
